@@ -17,12 +17,16 @@ test_that("dep_graph_next_package finds next installable package", {
   # initialize graph, such that "D" is not completed when "E"  would be next
   # by order due to "D" having a long install time
   V(g)$status <- STATUS[["pending"]]
+  V(g)$type <- "install"
   V(g)["D"]$status <- STATUS[["in progress"]]
   V(g)["C"]$status <- STATUS[["done"]]
-  expect_equal(task_graph_which_satisfied(g), "B")
+  g <- task_graph_update_ready(g)
+  expect_equal(names(task_graph_which_ready(g)), "B")
 
   # if the order is reversed, now "F" and "E" should be next
+  V(g)$status <- STATUS[["pending"]]
   V(g)["D"]$status <- STATUS[["done"]]
   V(g)["C"]$status <- STATUS[["in progress"]]
-  expect_equal(task_graph_which_satisfied(g), c("F", "E"))
+  g <- task_graph_update_ready(g)
+  expect_equal(names(task_graph_which_ready(g)), c("F", "E"))
 })
